==> realestate-supervise-common-1.0.0-20211126.015821-49-sources.jar: cn/gtmap/realestate/supervise/utils/SecurityDateSource.java <==
package cn.gtmap.realestate.supervise.utils;

import com.alibaba.druid.pool.DruidDataSource;
import org.apache.log4j.Logger;

import java.util.Scanner;

/**
 * @version 1.0 2019-6-13
 * @auther <a href="mailto:xutao@gtmap.cn">xutao</a>
 * @description
 */
public class SecurityDateSource extends DruidDataSource {

    Logger logger = Logger.getLogger(SecurityDateSource.class);

    @Override
    public void setPassword(String password) {
        try {
            password = AESSecutiryUtil.decrypt(password);
            super.setPassword(password);
        } catch (Exception e) {
            logger.error("数据源加密参数解密失败", e);
            super.setPassword("");
        }
    }

    public static void main(String[] args) throws Exception {
//        String password = "ok123";
//        String username = "root";
//        System.out.println("加密后的password = [" + ConfigTools.encrypt(password) + "]");
//        System.out.println("加密后的username = [" + ConfigTools.encrypt(username) + "]");
//
//        System.out.println("加密后的password = [" + ConfigTools.decrypt("TQahFhqOo8xPfraoAIkhQd0R85Z7c9/8cJEkq4fYG4PT9KpZhwpmEtW8PSSCZ9j7Q7NCWd8DZ3f0lJHsxr24bA==") + "]");
//        System.out.println("加密后的username = [" + ConfigTools.decrypt("bNVOqb7WKLX5Bjnw+LMv92taj25KOxDimXxILPQjw42wgv+1lHzOH8kr97xDwWdhpY67QuYCS7sWN4W46YbkFA==") + "]");

        while(true){
            System.out.print("请输入要加密的字符串：");
            Scanner scan = new Scanner(System.in);
            String read = scan.nextLine();
            System.out.println("加密之后：" + AESSecutiryUtil.encrypt(read));
        }
    }

}

==> realestate-supervise-common-1.1.0-20220818.055648-18-sources.jar: cn/gtmap/realestate/supervise/utils/SecurityDateSource.java <==
package cn.gtmap.realestate.supervise.utils;

import com.alibaba.druid.pool.DruidDataSource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Scanner;

/**
 * @version 1.0 2019-6-13
 * @auther <a href="mailto:xutao@gtmap.cn">xutao</a>
 * @description
 */
public class SecurityDateSource extends DruidDataSource {

    Logger logger = LoggerFactory.getLogger(SecurityDateSource.class);

    @Override
    public void setPassword(String password) {
        try {
            password = AESSecutiryUtil.decrypt(password);
            super.setPassword(password);
        } catch (Exception e) {
            logger.error("数据源加密参数解密失败", e);
            super.setPassword("");
        }
    }

    public static void main(String[] args) throws Exception {
//        String password = "ok123";
//        String username = "root";
//        System.out.println("加密后的password = [" + ConfigTools.encrypt(password) + "]");
//        System.out.println("加密后的username = [" + ConfigTools.encrypt(username) + "]");
//
//        System.out.println("加密后的password = [" + ConfigTools.decrypt("TQahFhqOo8xPfraoAIkhQd0R85Z7c9/8cJEkq4fYG4PT9KpZhwpmEtW8PSSCZ9j7Q7NCWd8DZ3f0lJHsxr24bA==") + "]");
//        System.out.println("加密后的username = [" + ConfigTools.decrypt("bNVOqb7WKLX5Bjnw+LMv92taj25KOxDimXxILPQjw42wgv+1lHzOH8kr97xDwWdhpY67QuYCS7sWN4W46YbkFA==") + "]");

        while(true){
            System.out.print("请输入要加密的字符串：");
            Scanner scan = new Scanner(System.in);
            String read = scan.nextLine();
            System.out.println("加密之后：" + AESSecutiryUtil.encrypt(read));
        }
    }

}
